---
hide:
  - navigation
  - toc
---

# mkdoclingo

This is an extension for automatic documentation of clingo encodings.
It is implemented as a plugin of [mkdocstrings](https://mkdocstrings.github.io/).


!!! info
    *mkdoclingo* is part of the [Potassco](https://potassco.org) suite.
